==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
export let WebSliderLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderLabelDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderLabelDescriptionMetadata.a == null) {
                WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
            }
            if (a.k(WebSliderLabelDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSliderLabelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderLabel");
            a.item("__tagNameWC", "String:igc-slider-label");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSliderLabelDescriptionMetadata.b(a);
            a.ad("WebSliderLabel", () => new WebSliderLabelDescription());
            a.ac("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
        }
    }
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
export let WebSliderLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderLabelDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderLabelDescriptionMetadata.a == null) {
                WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
            }
            if (a.k(WebSliderLabelDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSliderLabelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderLabel");
            a.item("__tagNameWC", "String:igc-slider-label");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSliderLabelDescriptionMetadata.b(a);
            a.ae("WebSliderLabel", () => new WebSliderLabelDescription());
            a.ad("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
        }
    }
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
})();
